# 保存模型
from sklearn.feature_extraction.text import TfidfVectorizer
from sklearn.naive_bayes import MultinomialNB
from sklearn.pipeline import make_pipeline
from sklearn.model_selection import train_test_split
from joblib import dump, load

# 假设你的数据是这样的：
# data = {"己所不欲，勿施于人。": "孔子", "近朱者赤，近墨者黑。": "墨子", ...}  # 字典格式的数据
data = {
    '落霞与孤鹜齐飞': '王勃',
    '秋水共长天一色。': '王勃',
    '关山难越，谁悲失路之人；萍水相逢，尽是他乡之客。': '王勃',
    '渔舟唱晚，响穷彭蠡之滨，雁阵惊寒，声断衡阳之浦。': '王勃',
    '物华天宝，龙光射牛斗之墟；人杰地灵，徐孺下陈蕃之榻。': '王勃',
    '闲云潭影日悠悠，物换星移几度秋。': '王勃',
    '老当益壮，宁移白首之心？穷且益坚，不坠青云之志。': '王勃',
    '潦水尽而寒潭清，烟光凝而暮山紫。': '王勃',
    '海内存知己': '王勃',
    '天涯若比邻。': '王勃',
    '心事同漂泊，生涯共苦辛。无论去与住，俱是梦中人。': '王勃',
    '长江悲已滞，万里念将归。': '王勃',
    '经耳不忘，历口不遗。': '杨炯',
    '朗如日月，清如水镜。': '杨炯',
    '风行常有地，云出本多峰。': '杨炯',
    '相思明月夜，迢递白云天。': '杨炯',
    '气如兰兮长不改': '杨炯',
    '心若兰兮终不移。': '杨炯',
    '居难则易，在塞咸通。': '杨炯',
    '言无法度不出于口': '杨炯',
    '行非公道不萌于心。': '杨炯',
    '其明察察，其政恂恂。': '杨炯',
    '事有古而可以质于今，言有大而可以征于小。': '杨炯',
    '富贵比于浮云，光阴逾于尺璧，著撰之志，自此居多。': '杨炯',
    '雪处疑花满，花边似雪回。': '卢照邻',
    '匈奴几万里': '卢照邻',
    '春至不知来': '卢照邻',
    '关山客子路，花柳帝王城。': '卢照邻',
    '此中一分手，相顾怜无声。': '卢照邻',
    '万里同为客': '卢照邻',
    '三秋契不凋': '卢照邻',
    '相思在万里，明月正孤悬。': '卢照邻',
    '寄言闺中妇，时看鸿雁天。': '卢照邻',
    '应须驻白日，为待战方酣。': '卢照邻',
    '北游君似智，南飞我异禽。': '卢照邻',
    '年华已可乐，高兴复留人。': '卢照邻',
    '白毛浮绿水': '骆宾王',
    '红掌拨清波。': '骆宾王',
    '此地别燕丹，壮士发冲冠。': '骆宾王',
    '昔时人已没': '骆宾王',
    '今日水犹寒。': '骆宾王',
    '平生一顾念，意气溢三军。': '骆宾王',
    '山河千里国，城阙九重门。': '骆宾王',
    '少年重英侠，弱岁贱衣冠。': '骆宾王',
    '寒更承夜永，凉夕向秋澄。': '骆宾王',
    '离心何以赠，自有玉壶冰。': '骆宾王',
    '繁花明日柳，疏蕊落风梅。': '骆宾王',
    '旧国千年尽，荒城四望通。': '骆宾王',
    # 添加更多的古文和作者...
}
# 将字典转化为两个列表
texts = list(data.keys())  # 文本数据
labels = list(data.values())  # 标签，即每个文本的作者

# 将数据分为训练集和测试集
texts_train, texts_test, labels_train, labels_test = train_test_split(texts, labels, test_size=0.1, random_state=1)

# 创建一个TfidfVectorizer对象，用于将文本转化为向量
vectorizer = TfidfVectorizer()

# 创建一个MultinomialNB对象，用于进行文本分类
classifier = MultinomialNB()

# 创建一个pipeline，将向量化和分类两个步骤组合起来
model = make_pipeline(vectorizer, classifier)

# 使用训练集训练模型
model.fit(texts_train, labels_train)

# 使用测试集评估模型
print(model.score(texts_test, labels_test))

# 保存模型
dump(model, 'model.joblib') 

print("模型保存完成！")
